#include "interrupts.h"


#ifdef __IAR_SYSTEMS_ICC__
  // empty interrupt table, IAR EWB v3 style of declaration
  #pragma vector=UART0TX_VECTOR
     __interrupt void intUart0Tx(void) {};
  #pragma vector=UART0RX_VECTOR
     __interrupt void intUart0Rx(void) {};   
  #pragma vector=PORT1_VECTOR
     __interrupt void intPort1(void) {};
  #pragma vector=ADC_VECTOR
     __interrupt void intADC(void) {};
  #pragma vector=TIMERA1_VECTOR
     __interrupt void intTimerA1(void) {};
  #pragma vector=TIMERA0_VECTOR
     __interrupt void intTimerA0(void) {};
  #pragma vector=TIMERB1_VECTOR
     __interrupt void intTimerB1(void) {};
  #pragma vector=TIMERB0_VECTOR
     __interrupt void intTimerB0(void) {};
  #pragma vector=COMPARATORA_VECTOR
     __interrupt void intComparator(void) {};
#else
  // empty interrupt table, MSP-GCC style of declaration
  interrupt (UART0TX_VECTOR) intUart0Tx(void) {};
  interrupt (UART0RX_VECTOR) intUart0Rx(void) {};  
  interrupt (PORT1_VECTOR) intPort1(void) {};
  interrupt (ADC_VECTOR) intADC(void) {};
  interrupt (TIMERA1_VECTOR) intTimerA1(void) {};
  interrupt (TIMERA0_VECTOR) intTimerA0(void) {};
  interrupt (TIMERB1_VECTOR) intTimerB1(void) {};
  interrupt (TIMERB0_VECTOR) intTimerB0(void) {};
  interrupt (COMPARATORA_VECTOR) intComparator(void) {};
#endif


// initInterrupts ( )
void initInterrupts(void) {

   _DINT();
   
   // -- reconfig watch dog timer as interval mode interrupt
   
   WDTCTL = WDTPW + WDTCNTCL + WDTTMSEL + WDTIS0;   
                                 // clear counter, interval mode
                                 // WDTIS0: 470..540Hz (SMCLK/8192)
                                 // - : 122..135Hz (SMCLK/32768)
   sys_ticks = 0;
   
   
   IE1 |= WDTIE;				// enable WDT interrupt


   
   _EINT();
   
   return;
}


//-------------------------------------------------------------------
// intWDT ( )
// Watchdog interrupt handler, with watchdog in interval counter mode.
// Advances the system tick counter. 1 tick = 8192/crystalfreq seconds.
// If using 8Mhz xtal clock: 1 tick = ~1.024ms
// 

#ifdef __IAR_SYSTEMS_ICC__
  #pragma vector=WDT_VECTOR
    __interrupt void intWDT(void)
#else
  interrupt (WDT_VECTOR) watchdog_timer(void)
#endif
{
   //#ifdef WDT_SYSTICK_DEBUG 
   
   if(sys_ticks == 100){
       
       P1OUT ^= LED_1; // blink the LED 
       sys_ticks = 0;
   }
   
   sys_ticks++; 
   
   //#endif
}
