/*************************************************************************
Title:    DEMO-Projekt for MSP430F1611-Board
Author:   (c) mgiaco <ecam@aon.at>  http://www.hkw-modelltechnik.de.vu
File:     main.c
Software: MSPGCC
Hardware: MSP430-Board (von Marcel Bammert)
**************************************************************************/

#include "main.h"

/*
/*
** constant definitions
*/

volatile unsigned int sys_ticks;    // counter, 1 tick = 8192/crystalfreq seconds

static const unsigned char copyRightChar[] = {
    //Def. Zeichen 0       
	0x07, // 0 0 0 0 0 1 1 1   
    0x08, // 0 0 0 0 1 0 0 0   
    0x13, // 0 0 0 1 0 0 1 1   
    0x14, // 0 0 0 1 0 1 0 0   
    0x14, // 0 0 0 1 0 1 0 0   
    0x13, // 0 0 0 1 0 0 1 1  
    0x08, // 0 0 0 0 1 0 0 0   
    0x07, // 0 0 0 0 0 1 1 1  
    //Def. Zeichen 1
	0x00, // 0 0 0 0 0 0 0 0
    0x10, // 0 0 0 1 0 0 0 0 
    0x08, // 0 0 0 0 1 0 0 0
    0x08, // 0 0 0 0 1 0 0 0
    0x08, // 0 0 0 0 1 0 0 0
    0x08, // 0 0 0 0 1 0 0 0
    0x10, // 0 0 0 1 0 0 0 0
    0x00  // 0 0 0 0 0 0 0 0
};
/*  
    so wird das Copyright Zeichen gemacht!
    die ersten 3 sind immer 0! Display hat
    ja 8 * 5 Punkte
     
    0 0 0 --> 0 0 1 1 1   0 0 0 --> 0 0 0 0 0
    0 0 0 --> 0 1 0 0 0   0 0 0 --> 1 0 0 0 0
    0 0 0 --> 1 0 0 1 1   0 0 0 --> 0 1 0 0 0
    0 0 0 --> 1 0 1 0 0   0 0 0 --> 0 1 0 0 0  
    0 0 0 --> 1 0 1 0 0   0 0 0 --> 0 1 0 0 0   
    0 0 0 --> 1 0 0 1 1   0 0 0 --> 0 1 0 0 0       
    0 0 0 --> 0 1 0 0 0   0 0 0 --> 1 0 0 0 0
    0 0 0 --> 0 0 1 1 1   0 0 0 --> 0 0 0 0 0
*/

/*
** function prototypes
*/ 
void wait_until_key_pressed(void);
void init(void);




/*
** main function
*/
int main(void){
    
    uint8_t i;
    
    init(); //Init CPU
    
        
    for (;;) { //loop forever
    
        // clear display and home cursor
        lcd_gotoxy(0,0);
        
        // put string to display
        lcd_puts("-- BOARD DEMO --");
              
        //load two userdefined characters from program memory
        //into LCD controller CG RAM location 0 and 1
        lcd_command(BV(LCD_CGRAM)); // set CG RAM start address 0
        for(i=0; i<16; i++){
           lcd_data(copyRightChar[i]);
        }
        // move cursor to position 0 on line 2 
        // Note: this switched back to DD RAM adresses
        lcd_gotoxy(0,1);
       
        // display user defined (c), built using two user defined chars
        lcd_putc(0);
        lcd_putc(1);
        
        /* wait until push the ENTER Button*/
        wait_until_key_pressed();  
            
        lcd_clrscr();
        lcd_puts(" DEMO STARTS \n");
        lcd_puts(" coming soon -:)");
        
        wait_until_key_pressed();        
              
    }
    return 0;
    
}

/*
** User functions
*/
void init(void){
     
    uint8_t i;
    
    //WDTCTL = WDTPW + WDTHOLD;       // stop watchdog timer  
      
    BCSCTL1 &= ~XT2OFF;             // XT2 = HF XTAL
    
    do{
       IFG1 &= ~OFIFG;              // Clear OSCFault flag
       for (i = 0xFF; i > 0; i--);  // Time for flag to set
    }while ((IFG1 & OFIFG));        // OSCFault flag still set?

    BCSCTL2 |= SELM_2;              // MCLK= XT2 (safe)
    
    P1DIR=0xF0; // or P1DIR = 0b00001111 port 1 = input (4 Taster) und output 3 LEDs
    P1OUT=0x00; // Leds ein
    
    P1SEL=0x00;            // port als GPIO nutzen, und nicht als Timer oder so ... 
    P1IE=0x00;             // Port 1 und 2 sind interruptfhig ==> interrupt ausmachen
    P2IE=0x00;             // interrupt ausmachen
    
    lcd_init(LCD_DISP_ON); // initialize display, cursor off 
    
    initInterrupts(); //Init Interrupts
    
}

void wait_until_key_pressed(void)
{
    unsigned char temp1, temp2;
    unsigned int i;
    
    do {
        temp1 = P1IN;                  // read input
        for(i=0;i<65535;i++);
        temp2 = P1IN;                  // read input
        temp1 = (temp1 & temp2);       // debounce input
    } while ( temp1 & (1 << 0) );
    
    do { } while (bit_is_clear(P1IN, 0));
   
}

